# VK-Botting

[![Documentation Status](https://readthedocs.org/projects/vk-botting/badge/?version=latest)](https://vk-botting.readthedocs.io/en/latest/?badge=latest)

vk_botting is a package for building async VK bots.<br>
It is in development so it can be buggy or not implement all latest features of VK API.<br>
That is also why it does not have full documentation atm.<br>
Partial docs: [Russian](https://vk-botting.readthedocs.io/ru/latest) or [English](https://vk-botting.readthedocs.io/en/latest).<br>
<br>
For any questions, suggestions or reports, use either [Telegram chat](https://t.me/vk_botting) or [GitHub Issues](https://github.com/MrDandycorn/vk-botting/issues).<br>
<br>
<br>
vk_botting - библиотека для создания асинхронных ботов для ВК.<br>
Она все еще в разработке, так что в некоторых местах может содержать баги, или же не полностью реализовывать все последние возможности VK API.<br>
По той же причине у нее на данный момент может не быть исчерпывающей документации.<br>
Частичная документация: [На русском](https://vk-botting.readthedocs.io/ru/latest) или [На английском](https://vk-botting.readthedocs.io/en/latest).<br>
<br>
Со всеми вопросами, предложениями и проблемами можете обращаться либо в [Чат Telegram](https://t.me/vk_botting), либо в [Раздел Issues на GitHub](https://github.com/MrDandycorn/vk-botting/issues).
